@@ -52,6 +52,8 @@ class Paths(object):
     @property
     def LOG_FILE(self):
         return os.path.expanduser('~/.instack/install-undercloud.log')
+
+
 PATHS = Paths()
 DEFAULT_LOG_LEVEL = logging.DEBUG
 DEFAULT_LOG_FORMAT = '%(asctime)s %(levelname)s: %(message)s'
@@ -488,6 +490,7 @@ def _generate_endpoints(instack_env):
     keystone_public_port = 5000
     swift_public_port = 8080
     ironic_public_port = 6385
+    ironic_inspector_public_port = 5050
     aodh_public_port = 8042
 
     if CONF.undercloud_service_certificate:
@@ -501,6 +504,7 @@ def _generate_endpoints(instack_env):
         keystone_public_port = 13000
         swift_public_port = 13808
         ironic_public_port = 13385
+        ironic_inspector_public_port = 13050
         aodh_public_port = 13042
 
     heat_public_params = (proto, public_host, heat_public_port)
@@ -527,6 +531,10 @@ def _generate_endpoints(instack_env):
     ironic_public_params = (proto, public_host, ironic_public_port)
     ironic_internal_params = ('http', local_host, 6385)
     ironic_admin_params = ironic_internal_params
+    ironic_inspector_public_params = (proto, public_host,
+                                      ironic_inspector_public_port)
+    ironic_inspector_internal_params = ('http', local_host, 5050)
+    ironic_inspector_admin_params = ironic_inspector_internal_params
     aodh_public_params = (proto, public_host, aodh_public_port)
     aodh_internal_params = ('http', local_host, 8042)
     aodh_admin_params = aodh_internal_params
@@ -599,6 +607,12 @@ def _generate_endpoints(instack_env):
                  ironic_internal_params,
                  ironic_admin_params,
                  )
+    add_endpoint('ironic_inspector',
+                 '%s://%s:%d',
+                 ironic_inspector_public_params,
+                 ironic_inspector_internal_params,
+                 ironic_inspector_admin_params,
+                 )
     add_endpoint('aodh',
                  '%s://%s:%d',
                  aodh_public_params,
@@ -729,6 +743,13 @@ def _run_instack(instack_env):
     LOG.info('Instack completed successfully')
 
 
+def _run_yum_update(instack_env):
+    args = ['sudo', 'yum', 'update', '-y']
+    LOG.info('Running yum update')
+    _run_live_command(args, instack_env, 'yum-update')
+    LOG.info('yum-update completed successfully')
+
+
 def _run_orc(instack_env):
     args = ['sudo', 'os-refresh-config']
     LOG.info('Running os-refresh-config')
@@ -841,6 +862,7 @@ def install(instack_root):
     _check_memory()
     _clean_os_refresh_config()
     instack_env = _generate_environment(instack_root)
+    _run_yum_update(instack_env)
     _run_instack(instack_env)
     _run_orc(instack_env)
     _post_config()
